from __future__ import absolute_import

import atexit
from pkg_resources import get_distribution, DistributionNotFound

import importlib_resources

try:
    from importlib_resources import as_file
except ImportError:
    from importlib_resources.trees import as_file

try:
    from contextlib import ExitStack
except ImportError:
    from contextlib2 import ExitStack

try:
    version = get_distribution(__name__).version
except DistributionNotFound:
    version = "unknown version"
__version__ = version

LATEST_VERSIONS = {
    "detx": "detx/detx_v3.detx",
}


def data_path(filename, raise_missing=True):
    """Return the absolute filepath for a given filename in test data"""
    ref = importlib_resources.files("km3net_testdata.data") / filename
    file_manager = ExitStack()
    atexit.register(file_manager.close)
    file_path = file_manager.enter_context(as_file(ref))
    if raise_missing and not file_path.exists():
        raise RuntimeError("Unknown or missing file: {0}".format(filename))
    return str(file_path)


def latest(dataformat, raise_missing=True):
    """Return the path to the latest version of the given dataformat"""
    filename = LATEST_VERSIONS.get(dataformat, "latest." + dataformat)
    return data_path(filename, raise_missing=raise_missing)


__all__ = ["data_path"]



"""
How to use the package
=======================

The following example shows how to use the `Calculator` class.
"""
from km3net_testdata import data_path

#####################################################
# Getting a filename
# ------------------
# To get the filename of a sample file:

filename = data_path("online/km3net_online.root")
print(filename)



"""
This file will be invoked by python when called with th `-m` options:
```
python -m skhep_testdata cms_hep_2012_tutorial/data.root
```
"""
from __future__ import print_function
import argparse
from . import data_path

if __name__ == "__main__":
    description = "Expand a testing dataset path to a full path."
    parser = argparse.ArgumentParser(prog="km3net_testdata")
    parser.add_argument("file_path", help="path to expand", type=str)
    args = parser.parse_args()

    path = data_path(args.file_path)
    print(path)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import unittest

from km3net_testdata import data_path, latest, LATEST_VERSIONS


class TestDataPath(unittest.TestCase):
    def test_access(self):
        assert data_path("online/km3net_online.root").endswith("km3net_online.root")

    def test_accessing_nonexistent_files(self):
        with self.assertRaises(RuntimeError):
            data_path("nonexistent_file")

    def test_filename_returned_if_raise_missing_is_false(self):
        filename = "nonexistent_file"
        assert data_path(filename, raise_missing=False).endswith(filename)


class TestLatest(unittest.TestCase):
    def test_latest_paths(self):
        for dataformat in LATEST_VERSIONS.keys():
            assert latest(dataformat).endswith(LATEST_VERSIONS[dataformat])



#!/usr/bin/env python
# Filename: setup.py
"""
The km3net_testdata setup script.

"""
from setuptools import setup
import sys


def read_stripped_lines(filename):
    """Return a list of stripped lines from a file"""
    with open(filename) as fobj:
        return [line.strip() for line in fobj.readlines()]


try:
    with open("README.rst") as fh:
        long_description = fh.read()
except UnicodeDecodeError:
    long_description = "KM3NeT TestData"

setup(
    name='km3net_testdata',
    url='https://git.km3net.de/km3py/km3net-testdata',
    description='KM3NeT TestData',
    long_description=long_description,
    author='Tamas Gal',
    author_email='tgal@km3net.de',
    packages=['km3net_testdata'],
    include_package_data=True,
    platforms='any',
    setup_requires=['setuptools_scm'],
    use_scm_version=True,
    python_requires='>=2.7',
    install_requires=read_stripped_lines("requirements.txt"),
    extras_require={"dev": read_stripped_lines("requirements-dev.txt")},
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python',
    ],
)
